Label
=====

The Label is a text-label for annotating forms or interfaces.

Usage
-----

.. code-block:: Python

    import toga
    
    label = toga.Label('Hello world')

Supported Platforms
-------------------

.. include:: ../supported_platforms/Label.rst

Reference
---------

.. autoclass:: toga.interface.widgets.label.Label
   :members:
   :undoc-members:
   :inherited-members: